<?php
$EM_CONF[$_EXTKEY] = [
    'title' => 'Frontend Login for Website Users',
    'description' => 'A template-based plugin to log in Website Users in the Frontend',
    'category' => 'plugin',
    'author' => 'TYPO3 Core Team',
    'author_email' => 'typo3cms@typo3.org',
    'author_company' => '',
    'state' => 'stable',
    'uploadfolder' => 0,
    'createDirs' => '',
    'clearCacheOnLoad' => 1,
    'version' => '9.5.14',
    'constraints' => [
        'depends' => [
            'typo3' => '9.5.14',
        ],
        'conflicts' => [],
        'suggests' => [],
    ],
];
